diff --git a/src/conversion/ensight/part/ensightPartCells.C b/src/conversion/ensight/part/ensightPartCells.C
index 82ef148e036d746dccbbfe3ecad76ce6c43b7fd0..dbf421539b310d0254e0fea200d1c32a5e900f5d 100644
--- a/src/conversion/ensight/part/ensightPartCells.C
+++ b/src/conversion/ensight/part/ensightPartCells.C
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011-2016 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2017 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
@@ -38,6 +38,8 @@ namespace Foam
     addToRunTimeSelectionTable(ensightPart, ensightPartCells, istream);
 }
 
+const Foam::polyMesh* const Foam::ensightPartCells::polyMeshNullPtr_ = nullptr;
+
 const Foam::List<Foam::word> Foam::ensightPartCells::elemTypes_
 (
     IStringStream
@@ -182,7 +184,7 @@ Foam::ensightPartCells::ensightPartCells
 )
 :
     ensightPart(partNumber, partDescription),
-    mesh_(*reinterpret_cast<polyMesh*>(0))
+    mesh_(*polyMeshNullPtr_)
 {}
 
 
@@ -237,7 +239,7 @@ Foam::ensightPartCells::ensightPartCells(const ensightPartCells& part)
 Foam::ensightPartCells::ensightPartCells(Istream& is)
 :
     ensightPart(),
-    mesh_(*reinterpret_cast<polyMesh*>(0))
+    mesh_(*polyMeshNullPtr_)
 {
     reconstruct(is);
 }
diff --git a/src/conversion/ensight/part/ensightPartCells.H b/src/conversion/ensight/part/ensightPartCells.H
index d1b3bcb72dbaf6bd307b5e5bd5b462910d29db8c..6a937abeba4bb0c7e1796491fa30a24082a51db0 100644
--- a/src/conversion/ensight/part/ensightPartCells.H
+++ b/src/conversion/ensight/part/ensightPartCells.H
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011-2015 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2017 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
@@ -94,6 +94,8 @@ protected:
 
     // Static data members
 
+        static const polyMesh* const polyMeshNullPtr_;
+
         static const List<word> elemTypes_;
 
 
diff --git a/src/meshTools/edgeFaceCirculator/edgeFaceCirculator.H b/src/meshTools/edgeFaceCirculator/edgeFaceCirculator.H
index 8aa85d978b9a715356ebd48d1e2e16567b9785dc..c9b8ac0708bc8a5aada087094f5749f375580f27 100644
--- a/src/meshTools/edgeFaceCirculator/edgeFaceCirculator.H
+++ b/src/meshTools/edgeFaceCirculator/edgeFaceCirculator.H
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011-2016 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2017 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
@@ -88,6 +88,9 @@ class edgeFaceCirculator
 {
     // Static data members
 
+        //- End iterator primitiveMesh nullptr
+        static const primitiveMesh* const endConstIterMeshPtr;
+
         //- End iterator
         static const edgeFaceCirculator endConstIter;
diff --git a/src/meshTools/edgeFaceCirculator/edgeFaceCirculator.C b/src/meshTools/edgeFaceCirculator/edgeFaceCirculator.C
index 9149eaf92004d857a4689402ac26136cfffd0119..5431bb419fb2b14f644a96cb528e15f9c34389c0 100644
--- a/src/meshTools/edgeFaceCirculator/edgeFaceCirculator.C
+++ b/src/meshTools/edgeFaceCirculator/edgeFaceCirculator.C
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2017 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
@@ -28,13 +28,16 @@ License
 
 // * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //
 
+const Foam::primitiveMesh* const Foam::edgeFaceCirculator::endConstIterMeshPtr
+    = nullptr;
+
 const Foam::edgeFaceCirculator Foam::edgeFaceCirculator::endConstIter
 (
-    *reinterpret_cast<primitiveMesh*>(0),       // primitiveMesh
-    -1,                                         // faceLabel
-    false,                                      // ownerSide
-    -1,                                         // index
-    false                                       // isBoundaryEdge
+    *Foam::edgeFaceCirculator::endConstIterMeshPtr, // primitiveMesh
+    -1,                                             // faceLabel
+    false,                                          // ownerSide
+    -1,                                             // index
+    false                                           // isBoundaryEdge
 );
 
 